from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, String

Storescu_V0_1_0 = CommandToolBuilder(tool="storescu", base_command=["storescu"], inputs=[ToolInput(tag="in_arguments", input_type=Boolean(optional=True), prefix="--arguments", doc=InputDocumentation(doc="print expanded command line arguments")), ToolInput(tag="in_quiet", input_type=Boolean(optional=True), prefix="--quiet", doc=InputDocumentation(doc="quiet mode, print no warnings and errors")), ToolInput(tag="in_verbose", input_type=Boolean(optional=True), prefix="--verbose", doc=InputDocumentation(doc="verbose mode, print processing details")), ToolInput(tag="in_debug", input_type=Boolean(optional=True), prefix="--debug", doc=InputDocumentation(doc="debug mode, print debug information")), ToolInput(tag="in_log_level", input_type=Boolean(optional=True), prefix="--log-level", doc=InputDocumentation(doc="[l]evel: string constant\n(fatal, error, warn, info, debug, trace)\nuse level l for the logger")), ToolInput(tag="in_log_config", input_type=Boolean(optional=True), prefix="--log-config", doc=InputDocumentation(doc="[f]ilename: string\nuse config file f for the logger")), ToolInput(tag="in_read_dataset", input_type=Boolean(optional=True), prefix="--read-dataset", doc=InputDocumentation(doc="read data set without file meta information")), ToolInput(tag="in_no_recurse", input_type=Boolean(optional=True), prefix="--no-recurse", doc=InputDocumentation(doc="do not recurse within directories (default)")), ToolInput(tag="in_no_rename", input_type=Boolean(optional=True), prefix="--no-rename", doc=InputDocumentation(doc="do not rename processed files (default)")), ToolInput(tag="in_ae_title", input_type=Boolean(optional=True), prefix="--aetitle", doc=InputDocumentation(doc="[a]etitle: string\nset my calling AE title (default: STORESCU)")), ToolInput(tag="in_call", input_type=Boolean(optional=True), prefix="--call", doc=InputDocumentation(doc="[a]etitle: string\nset called AE title of peer (default: ANY-SCP)")), ToolInput(tag="in_config_file", input_type=Boolean(optional=True), prefix="--config-file", doc=InputDocumentation(doc="[f]ilename, [p]rofile: string\nuse profile p from config file f")), ToolInput(tag="in__proposeuncompr_propose", input_type=Boolean(optional=True), prefix="-x", doc=InputDocumentation(doc="=   --propose-uncompr       propose all uncompressed TS, explicit VR\nwith local byte ordering first (default)")), ToolInput(tag="in_propose_little", input_type=Boolean(optional=True), prefix="--propose-little", doc=InputDocumentation(doc="propose all uncompressed TS, explicit VR\nlittle endian first")), ToolInput(tag="in_propose_big", input_type=Boolean(optional=True), prefix="--propose-big", doc=InputDocumentation(doc="propose all uncompressed TS, explicit VR\nbig endian first")), ToolInput(tag="in_propose_implicit", input_type=Boolean(optional=True), prefix="--propose-implicit", doc=InputDocumentation(doc="propose implicit VR little endian TS only")), ToolInput(tag="in_propose_lossless", input_type=Boolean(optional=True), prefix="--propose-lossless", doc=InputDocumentation(doc="propose default JPEG lossless TS\nand all uncompressed transfer syntaxes")), ToolInput(tag="in_propose_jpeg_eight", input_type=Boolean(optional=True), prefix="--propose-jpeg8", doc=InputDocumentation(doc="propose default JPEG lossy TS for 8 bit data\nand all uncompressed transfer syntaxes")), ToolInput(tag="in_propose_jpeg_one_two", input_type=Boolean(optional=True), prefix="--propose-jpeg12", doc=InputDocumentation(doc="propose default JPEG lossy TS for 12 bit data\nand all uncompressed transfer syntaxes")), ToolInput(tag="in_propose_j_two_k_lossless", input_type=Boolean(optional=True), prefix="--propose-j2k-lossless", doc=InputDocumentation(doc="propose JPEG 2000 lossless TS\nand all uncompressed transfer syntaxes")), ToolInput(tag="in_propose_j_two_k_lossy", input_type=Boolean(optional=True), prefix="--propose-j2k-lossy", doc=InputDocumentation(doc="propose JPEG 2000 lossy TS\nand all uncompressed transfer syntaxes")), ToolInput(tag="in_propose_jls_lossless", input_type=Boolean(optional=True), prefix="--propose-jls-lossless", doc=InputDocumentation(doc="propose JPEG-LS lossless TS\nand all uncompressed transfer syntaxes")), ToolInput(tag="in_propose_jls_lossy", input_type=Boolean(optional=True), prefix="--propose-jls-lossy", doc=InputDocumentation(doc="propose JPEG-LS lossy TS\nand all uncompressed transfer syntaxes")), ToolInput(tag="in_propose_mpeg_two", input_type=Boolean(optional=True), prefix="--propose-mpeg2", doc=InputDocumentation(doc="propose MPEG2 Main Profile @ Main Level TS")), ToolInput(tag="in_propose_mpeg_two_high", input_type=Boolean(optional=True), prefix="--propose-mpeg2-high", doc=InputDocumentation(doc="propose MPEG2 Main Profile @ High Level TS")), ToolInput(tag="in_propose_mpeg_four", input_type=Boolean(optional=True), prefix="--propose-mpeg4", doc=InputDocumentation(doc="propose MPEG4 AVC/H.264 HP / Level 4.1 TS")), ToolInput(tag="in_propose_mpeg_four_bd", input_type=Boolean(optional=True), prefix="--propose-mpeg4-bd", doc=InputDocumentation(doc="propose MPEG4 AVC/H.264 BD-compatible TS")), ToolInput(tag="in_propose_mpeg_four_two_two_d", input_type=Boolean(optional=True), prefix="--propose-mpeg4-2-2d", doc=InputDocumentation(doc="propose MPEG4 AVC/H.264 HP / Level 4.2 TS (2D)")), ToolInput(tag="in_propose_mpeg_four_two_three_d", input_type=Boolean(optional=True), prefix="--propose-mpeg4-2-3d", doc=InputDocumentation(doc="propose MPEG4 AVC/H.264 HP / Level 4.2 TS (3D)")), ToolInput(tag="in_propose_mpeg_four_two_st", input_type=Boolean(optional=True), prefix="--propose-mpeg4-2-st", doc=InputDocumentation(doc="propose MPEG4 AVC/H.264 Stereo / Level 4.2 TS")), ToolInput(tag="in_propose_he_vc", input_type=Boolean(optional=True), prefix="--propose-hevc", doc=InputDocumentation(doc="propose HEVC/H.265 Main Profile / Level 5.1 TS")), ToolInput(tag="in_propose_he_vc_one_zero", input_type=Boolean(optional=True), prefix="--propose-hevc10", doc=InputDocumentation(doc="propose HEVC/H.265 Main 10 Profile / Level 5.1 TS")), ToolInput(tag="in_propose_rle", input_type=Boolean(optional=True), prefix="--propose-rle", doc=InputDocumentation(doc="propose RLE lossless TS\nand all uncompressed transfer syntaxes")), ToolInput(tag="in_propose_deflated", input_type=Boolean(optional=True), prefix="--propose-deflated", doc=InputDocumentation(doc="propose deflated expl. VR little endian TS\nand all uncompressed transfer syntaxes")), ToolInput(tag="in_required", input_type=Boolean(optional=True), prefix="--required", doc=InputDocumentation(doc="propose only required presentation contexts\n(default: propose all supported)")), ToolInput(tag="in_disable_new_vr", input_type=Boolean(optional=True), prefix="--disable-new-vr", doc=InputDocumentation(doc="disable support for new VRs, convert to OB")), ToolInput(tag="in_user", input_type=Boolean(optional=True), prefix="--user", doc=InputDocumentation(doc="[u]ser name: string\nauthenticate using user name u")), ToolInput(tag="in_password", input_type=Boolean(optional=True), prefix="--password", doc=InputDocumentation(doc="[p]assword: string (only with --user)\nauthenticate using password p")), ToolInput(tag="in_empty_password", input_type=Boolean(optional=True), prefix="--empty-password", doc=InputDocumentation(doc="send empty password (only with --user)")), ToolInput(tag="in_kerberos", input_type=Boolean(optional=True), prefix="--kerberos", doc=InputDocumentation(doc="[f]ilename: string\nread kerberos ticket from file f")), ToolInput(tag="in_saml", input_type=Boolean(optional=True), prefix="--saml", doc=InputDocumentation(doc="[f]ilename: string\nread SAML request from file f")), ToolInput(tag="in_jwt", input_type=Boolean(optional=True), prefix="--jwt", doc=InputDocumentation(doc="[f]ilename: string\nread JWT data from file f")), ToolInput(tag="in_pos_response", input_type=Boolean(optional=True), prefix="--pos-response", doc=InputDocumentation(doc="expect positive response")), ToolInput(tag="in_timeout", input_type=Boolean(optional=True), prefix="--timeout", doc=InputDocumentation(doc="[s]econds: integer (default: unlimited)\ntimeout for connection requests")), ToolInput(tag="in_socket_timeout", input_type=Boolean(optional=True), prefix="--socket-timeout", doc=InputDocumentation(doc="[s]econds: integer (default: 60)\ntimeout for network socket (0 for none)")), ToolInput(tag="in_acse_timeout", input_type=Boolean(optional=True), prefix="--acse-timeout", doc=InputDocumentation(doc="[s]econds: integer (default: 30)\ntimeout for ACSE messages")), ToolInput(tag="in_dim_se_timeout", input_type=Boolean(optional=True), prefix="--dimse-timeout", doc=InputDocumentation(doc="[s]econds: integer (default: unlimited)\ntimeout for DIMSE messages")), ToolInput(tag="in_max_pdu", input_type=Boolean(optional=True), prefix="--max-pdu", doc=InputDocumentation(doc="[n]umber of bytes: integer (4096..131072)\nset max receive pdu to n bytes (default: 16384)")), ToolInput(tag="in_max_send_pdu", input_type=Boolean(optional=True), prefix="--max-send-pdu", doc=InputDocumentation(doc="[n]umber of bytes: integer (4096..131072)\nrestrict max send pdu to n bytes")), ToolInput(tag="in_repeat", input_type=Boolean(optional=True), prefix="--repeat", doc=InputDocumentation(doc="[n]umber: integer\nrepeat n times")), ToolInput(tag="in_abort", input_type=Boolean(optional=True), prefix="--abort", doc=InputDocumentation(doc="abort association instead of releasing it")), ToolInput(tag="in_no_halt", input_type=Boolean(optional=True), prefix="--no-halt", doc=InputDocumentation(doc="do not halt if unsuccessful store encountered\n(default: do halt)")), ToolInput(tag="in_uid_padding", input_type=Boolean(optional=True), prefix="--uid-padding", doc=InputDocumentation(doc="silently correct space-padded UIDs")), ToolInput(tag="in_disable_tls", input_type=Boolean(optional=True), prefix="--disable-tls", doc=InputDocumentation(doc="use normal TCP/IP connection (default)")), ToolInput(tag="in_null_passwd", input_type=Boolean(optional=True), prefix="--null-passwd", doc=InputDocumentation(doc="use empty string as password")), ToolInput(tag="in_pem_keys", input_type=Boolean(optional=True), prefix="--pem-keys", doc=InputDocumentation(doc="read keys and certificates as PEM file (default)")), ToolInput(tag="in_der_keys", input_type=Boolean(optional=True), prefix="--der-keys", doc=InputDocumentation(doc="read keys and certificates as DER file")), ToolInput(tag="in_require_peer_cert", input_type=Boolean(optional=True), prefix="--require-peer-cert", doc=InputDocumentation(doc="verify peer certificate, fail if absent (default)")), ToolInput(tag="in_ignore_peer_cert", input_type=Boolean(optional=True), prefix="--ignore-peer-cert", doc=InputDocumentation(doc="don't verify peer certificate")), ToolInput(tag="in_peer", input_type=String(), position=0, doc=InputDocumentation(doc="hostname of DICOM peer")), ToolInput(tag="in_port", input_type=String(), position=1, doc=InputDocumentation(doc="tcp/ip port number of peer")), ToolInput(tag="in_dcm_file_in", input_type=String(), position=2, doc=InputDocumentation(doc="DICOM file or directory to be transmitted")), ToolInput(tag="in_sent", input_type=String(), position=0, doc=InputDocumentation(doc="+IR   --invent-series      [n]umber: integer (implies --invent-instance)")), ToolInput(tag="in_string", input_type=String(), position=0, doc=InputDocumentation(doc="use specified password"))], outputs=[], container="quay.io/biocontainers/dcmtk:3.6.5--h5fca97b_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Storescu_V0_1_0().translate("wdl")

